package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.CommConstant;
import com.huiju.estateagents.entity.TaBuildingFloor;
import com.huiju.estateagents.service.ITaBuildingFloorService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;

/**
 * <p>
    * 楼层表  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2020-02-10
 */
@RestController
@RequestMapping("/api")
public class TaBuildingFloorController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaBuildingFloorController.class);

    @Autowired
    public ITaBuildingFloorService iTaBuildingFloorService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/taBuildingFloor",method= RequestMethod.GET)
    public ResponseBean taBuildingFloorList(@RequestParam(value = "buildingId") String buildingId,
                                            @RequestParam(value = "blockId",required = false) Integer blockId,
                                            @RequestParam(value = "unitid",required = false) Integer unitId,
                                            @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                            @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaBuildingFloor> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaBuildingFloor> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("org_id",getOrgId(request));
            queryWrapper.eq("building_id",buildingId);
            queryWrapper.eq("status", CommConstant.STATUS_NORMAL);
            queryWrapper.eq(null != blockId,"block_id",blockId);
            queryWrapper.eq(null != unitId,"unit_id",unitId);
            queryWrapper.orderByDesc("create_date");

            IPage<TaBuildingFloor> result = iTaBuildingFloorService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taBuildingFloorList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taBuildingFloor 实体对象
     * @return
     */
    @RequestMapping(value="/taBuildingFloor",method= RequestMethod.POST)
    public ResponseBean taBuildingFloorAdd(@RequestBody TaBuildingFloor taBuildingFloor){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaBuildingFloorService.save(taBuildingFloor)){
                responseBean.addSuccess(taBuildingFloor);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taBuildingFloorAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taBuildingFloor/{id}", method= RequestMethod.DELETE)
    public ResponseBean taBuildingFloorDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaBuildingFloorService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taBuildingFloorDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taBuildingFloor 实体对象
     * @return
     */
    @RequestMapping(value="/taBuildingFloor/{id}",method= RequestMethod.PUT)
    public ResponseBean taBuildingFloorUpdate(@PathVariable Integer id,
                                              @RequestBody TaBuildingFloor taBuildingFloor){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaBuildingFloorService.updateById(taBuildingFloor)){
                responseBean.addSuccess(taBuildingFloor);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taBuildingFloorUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taBuildingFloor/{id}",method= RequestMethod.GET)
    public ResponseBean taBuildingFloorGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaBuildingFloorService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taBuildingFloorDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
