package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.entity.TaBuildingTerm;
import com.huiju.estateagents.service.ITaBuildingTermService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * <p>
    * 楼栋期表  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2020-02-12
 */
@RestController
@RequestMapping("/")
public class TaBuildingTermController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaBuildingTermController.class);

    @Autowired
    public ITaBuildingTermService iTaBuildingTermService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taBuildingTerm",method= RequestMethod.GET)
    public ResponseBean taBuildingTermList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                           @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaBuildingTerm> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaBuildingTerm> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaBuildingTerm> result = iTaBuildingTermService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taBuildingTermList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taBuildingTerm 实体对象
     * @return
     */
    @RequestMapping(value="/taBuildingTerm",method= RequestMethod.POST)
    public ResponseBean taBuildingTermAdd(@RequestBody TaBuildingTerm taBuildingTerm){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaBuildingTermService.save(taBuildingTerm)){
                responseBean.addSuccess(taBuildingTerm);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taBuildingTermAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taBuildingTerm/{id}", method= RequestMethod.DELETE)
    public ResponseBean taBuildingTermDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaBuildingTermService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taBuildingTermDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taBuildingTerm 实体对象
     * @return
     */
    @RequestMapping(value="/taBuildingTerm/{id}",method= RequestMethod.PUT)
    public ResponseBean taBuildingTermUpdate(@PathVariable Integer id,
                                        @RequestBody TaBuildingTerm taBuildingTerm){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaBuildingTermService.updateById(taBuildingTerm)){
                responseBean.addSuccess(taBuildingTerm);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taBuildingTermUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taBuildingTerm/{id}",method= RequestMethod.GET)
    public ResponseBean taBuildingTermGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaBuildingTermService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taBuildingTermDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
