package com.huiju.estateagents.controller;

import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.CommConstant;
import com.huiju.estateagents.entity.TaBuildingRoom;
import com.huiju.estateagents.entity.TaHousingResources;
import com.huiju.estateagents.service.ITaBuildingRoomService;
import com.huiju.estateagents.service.ITaHousingResourcesService;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * <p>
 * 房源表  前端控制器
 * </p>
 *
 * @author jobob
 * @since 2020-02-10
 */
@RestController
@RequestMapping("/api")
public class TaHousingResourcesController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaHousingResourcesController.class);

    @Autowired
    public ITaHousingResourcesService iTaHousingResourcesService;

    @Autowired
    private ITaBuildingRoomService taBuildingRoomService;

    /**
     * 分页查询列表
     *
     * @param salesBatchId
     * @param buildingId
     * @param pageNumber
     * @param pageSize
     * @param request
     * @return
     */
    @RequestMapping(value = "/admin/taHousingResources", method = RequestMethod.GET)
    public ResponseBean taHousingResourcesList(@RequestParam(value = "salesBatchId", required = true) Integer salesBatchId,
                                               @RequestParam(value = "buildingId", required = true) String buildingId,
                                               @RequestParam(value = "termName", required = false) String termName,
                                               @RequestParam(value = "blockName", required = false) String blockName,
                                               @RequestParam(value = "unitName", required = false) String unitName,
                                               @RequestParam(value = "floorName", required = false) String floorName,
                                               @RequestParam(value = "roomName", required = false) String roomName,
                                               @RequestParam(value = "apartmentId", required = false) String apartmentId,
                                               @RequestParam(value = "status", required = false) Integer status,
                                               @RequestParam(value = "houseId", required = false) String houseId,
                                               @RequestParam(value = "pageNumber", defaultValue = "1") Integer pageNumber,
                                               @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                                               HttpServletRequest request) {
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean = iTaHousingResourcesService.selectPageList(salesBatchId, buildingId, pageNumber, pageSize, getOrgId(request), termName, blockName, unitName, floorName, roomName, apartmentId, status, houseId);
        } catch (Exception e) {
            e.printStackTrace();
            logger.error("taHousingResourcesList -=- {}", e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     *
     * @param taHousingResources 实体对象
     * @return
     */
    @RequestMapping(value = "/admin/taHousingResources", method = RequestMethod.POST)
    public ResponseBean taHousingResourcesAdd(@RequestBody TaHousingResources taHousingResources,HttpServletRequest request) {
        ResponseBean responseBean = new ResponseBean();
        try {
            taHousingResources.setOrgId(getOrgId(request));
            responseBean = iTaHousingResourcesService.addHouseResources(taHousingResources);
        } catch (Exception e) {
            e.printStackTrace();
            logger.error("taHousingResourcesAdd -=- {}", e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     *
     * @param id 实体ID
     */
    @ResponseBody
    @RequestMapping(value = "/admin/houseDelete/{id}", method = RequestMethod.DELETE)
    public ResponseBean taHousingResourcesDelete(@PathVariable Integer id) {
        ResponseBean responseBean = new ResponseBean();
        try {
            TaHousingResources taHousingResources = new TaHousingResources();
            taHousingResources.setHouseId(id);
            taHousingResources.setStatus(CommConstant.STATUS_DELETE);
            if (iTaHousingResourcesService.updateById(taHousingResources)) {
                //删除房号
                TaHousingResources housingResources = iTaHousingResourcesService.getById(id);
                TaBuildingRoom taBuildingRoom = new TaBuildingRoom();
                taBuildingRoom.setRoomId(housingResources.getRoomId());
                taBuildingRoom.setStatus(CommConstant.STATUS_DELETE);
                taBuildingRoomService.updateById(taBuildingRoom);
                responseBean.addSuccess("success");
            } else {
                responseBean.addError("fail");
            }
        } catch (Exception e) {
            e.printStackTrace();
            logger.error("taHousingResourcesDelete -=- {}", e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     *
     * @param id                 实体ID
     * @param taHousingResources 实体对象
     * @return
     */
    @RequestMapping(value = "/admin/taHousingResources/{id}", method = RequestMethod.PUT)
    public ResponseBean taHousingResourcesUpdate(@PathVariable Integer id,
                                                 @RequestBody TaHousingResources taHousingResources,HttpServletRequest request) {
        ResponseBean responseBean = new ResponseBean();
        try {
            taHousingResources.setHouseId(id);
            taHousingResources.setUpdateUser(getUserId(request));
            taHousingResources.setOrgId(getOrgId(request));
            responseBean = iTaHousingResourcesService.updateHouseResources(taHousingResources);
        } catch (Exception e) {
            e.printStackTrace();
            logger.error("taHousingResourcesUpdate -=- {}", e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改户型
     */
    @RequestMapping(value = "/admin/house/changeApartment", method = RequestMethod.PUT)
    public ResponseBean houseApartment(@RequestBody TaHousingResources taHousingResources,HttpServletRequest request) {
        ResponseBean responseBean = new ResponseBean();
        try {
            List<TaHousingResources> houseIdList = taHousingResources.getHouseIdList();
            houseIdList.forEach(e -> {
                e.setApartmentId(taHousingResources.getApartmentId());
            });
            iTaHousingResourcesService.updateBatchById(houseIdList);
            responseBean.addSuccess(houseIdList);
        } catch (Exception e) {
            e.printStackTrace();
            logger.error("taHousingResourcesUpdate -=- {}", e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     *
     * @param id 实体ID
     */
    @RequestMapping(value = "/admin/taHousingResources/{id}", method = RequestMethod.GET)
    public ResponseBean taHousingResourcesGet(@PathVariable Integer id) {
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaHousingResourcesService.getById(id));
        } catch (Exception e) {
            e.printStackTrace();
            logger.error("taHousingResourcesDelete -=- {}", e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 获取房源列表
     *
     * @param pageNum      页码
     * @param pageSize     分页大小
     * @param salesBatchId 销售批次ID
     * @return
     * @author gushaoyong
     */
    @RequestMapping(value = "/wx/listHousingResources", method = RequestMethod.GET)
    public ResponseBean listHousingResources(@RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                             @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                                             @RequestParam(value = "salesBatchId") String salesBatchId,
                                             String startPrice, String endPrice, String apartmentId) {
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaHousingResourcesService.listHousingResources(pageNum, pageSize, salesBatchId, startPrice, endPrice, apartmentId));
        } catch (Exception e) {
            logger.error("listHousingResources -=- {}", e);
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 获取某销售批次下所有房源户型
     *
     * @param salesBatchId
     * @return
     * @author gushaoyong
     */
    @RequestMapping(value = "/wx/listBuildApartmentBySalesBatchId", method = RequestMethod.GET)
    public ResponseBean listBuildApartmentBySalesBatchId(@RequestParam(value = "salesBatchId") String salesBatchId) {
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaHousingResourcesService.listBuildApartmentBySalesBatchId(salesBatchId));
        } catch (Exception e) {
            logger.error("listBuildApartmentBySalesBatchId -=- {}", e);
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据房源ID获取房源详情
     *
     * @param houseId
     * @return
     * @author gushaoyong
     */
    @RequestMapping(value = "/wx/getHousingDetailById", method = RequestMethod.GET)
    public ResponseBean getHousingDetailById(@RequestParam(value = "houseId") String houseId,
                                             @RequestParam(value = "personId") String personId) {
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaHousingResourcesService.getHousingDetailById(personId, houseId));
        } catch (Exception e) {
            logger.error("getHousingDetailById -=- {}", e);
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }


    /**
     * 校验房源是否合格
     *
     * @return
     */
    @RequestMapping(value = "/admin/house/checked", method = RequestMethod.PUT)
    public ResponseBean houseChecked(@RequestBody TaHousingResources taHousingResources,HttpServletRequest request) {
        ResponseBean responseBean = new ResponseBean();
        try {
            taHousingResources.setOrgId(getOrgId(request));
            StringBuffer result = iTaHousingResourcesService.checked(taHousingResources);
            responseBean.addSuccess(result);
        } catch (Exception e) {
            e.printStackTrace();
            logger.error("taHousingResourcesUpdate -=- {}", e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    @PostMapping(value = "/admin/house/uploadExcel")
    public ResponseBean uploadExcel(@RequestParam("file") MultipartFile file) {
        ResponseBean responseBean = new ResponseBean();
        responseBean = iTaHousingResourcesService.getExcelData(file);
        return responseBean;
    }
}
