package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.entity.TaSalesBatch;
import com.huiju.estateagents.service.ITaSalesBatchService;
import io.swagger.models.auth.In;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import sun.misc.Request;

import javax.servlet.http.HttpServletRequest;
import java.time.LocalDateTime;

/**
 * <p>
    * 销售批次表  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2020-02-10
 */
@RestController
@RequestMapping("/api")
public class TaSalesBatchController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaSalesBatchController.class);

    @Autowired
    public ITaSalesBatchService iTaSalesBatchService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/taSalesBatch",method= RequestMethod.GET)
    public ResponseBean taSalesBatchList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                         @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                         @RequestParam(value ="salesBatchName", required = false) String salesBatchName,
                                         @RequestParam(value ="buildingId", required = false) String buildingId,
                                         @RequestParam(value = "status", required = false) Integer status, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaSalesBatch> pg = new Page<>(pageNum, pageSize);

            IPage<TaSalesBatch> result = iTaSalesBatchService.selectByCondition(pg, salesBatchName, buildingId, status, getOrgId(request));
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taSalesBatchList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taSalesBatch 实体对象
     * @return
     */
    @RequestMapping(value="/admin/taSalesBatch",method= RequestMethod.POST)
    public ResponseBean taSalesBatchAdd(@RequestBody TaSalesBatch taSalesBatch, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            taSalesBatch.setOrgId(getOrgId(request));
            taSalesBatch.setCreateDate(LocalDateTime.now());
            taSalesBatch.setUpdateTime(LocalDateTime.now());
            if (iTaSalesBatchService.save(taSalesBatch)){
                responseBean.addSuccess(taSalesBatch);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taSalesBatchAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/admin/taSalesBatch/{id}", method= RequestMethod.DELETE)
    public ResponseBean taSalesBatchDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaSalesBatchService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taSalesBatchDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taSalesBatch 实体对象
     * @return
     */
    @RequestMapping(value="/admin/taSalesBatch/{id}",method= RequestMethod.PUT)
    public ResponseBean taSalesBatchUpdate(@PathVariable Integer id,
                                           @RequestBody TaSalesBatch taSalesBatch){
        ResponseBean responseBean = new ResponseBean();
        try {
            taSalesBatch.setSalesBatchId(id);
            if (iTaSalesBatchService.updateById(taSalesBatch)){
                responseBean.addSuccess(taSalesBatch);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taSalesBatchUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/taSalesBatch/{id}",method= RequestMethod.GET)
    public ResponseBean taSalesBatchGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaSalesBatchService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taSalesBatchDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
