package com.huiju.estateagents.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.IService;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.entity.TaBuildingApartment;
import com.huiju.estateagents.entity.TaHousingResources;
import com.huiju.estateagents.po.TaHousingResourcesPO;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

/**
 * <p>
 * 房源表  服务类
 * </p>
 *
 * @author jobob
 * @since 2020-02-10
 */
public interface ITaHousingResourcesService extends IService<TaHousingResources> {

    /* 分页获取房源列表
     *
     * @param pageNum      页码
     * @param pageSize     分页大小
     * @param salesBatchId 销售批次ID
     * @param startPrice
     * @param endPrice
     * @param apartmentId
     * @return
     */
    IPage<TaHousingResourcesPO> listHousingResources(Integer pageNum, Integer pageSize, String salesBatchId, String startPrice, String endPrice, String apartmentId);

    /**
     * 获取某销售批次下所有房源户型
     *
     * @param salesBatchId
     * @return
     */
    List<TaBuildingApartment> listBuildApartmentBySalesBatchId(String salesBatchId);

    /**
     * 根据房源ID获取房源详情
     *
     * @param personId
     * @param houseId
     * @return
     */
    TaHousingResourcesPO getHousingDetailById(String personId,String houseId);

    /**
     * 校验楼栋信息存不存在
     * @param taHousingResources
     * @return
     */
    StringBuffer checked(TaHousingResources taHousingResources);

    /**
     * 添加楼栋信息
     * @param taHousingResources
     * @return
     */
    ResponseBean addHouseResources(TaHousingResources taHousingResources);

    /**
     * 分页获取房源信息
     * @param salesBatchId
     * @param buildingId
     * @param pageNumber
     * @param pageSize
     * @param orgId
     * @param termName
     * @param blockName
     * @param unitName
     * @param floorName
     * @param roomName
     * @param apartmentId
     * @param status
     * @param houseId
     * @return
     */
    ResponseBean selectPageList(Integer salesBatchId, String buildingId, Integer pageNumber, Integer pageSize, Integer orgId, String termName, String blockName, String unitName, String floorName, String roomName, String apartmentId, Integer status, String houseId);

    /**
     * 更新房源信息
     * @param taHousingResources
     * @return
     */
    ResponseBean updateHouseResources(TaHousingResources taHousingResources);

    /**
     * 获取表格中的数据
     * @param file
     * @return
     */
    ResponseBean getExcelData(MultipartFile file);
}
