package com.huiju.estateagents.third.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.service.IMiniAppService;
import com.huiju.estateagents.third.entity.TaThirdPartyMiniappConfig;
import com.huiju.estateagents.third.service.ITaThirdPartyMiniappConfigService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;

/**
 * <p>
    *   前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-10-17
 */
@RestController
@RequestMapping("/api")
public class TaThirdPartyMiniappConfigController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaThirdPartyMiniappConfigController.class);

    @Autowired
    public ITaThirdPartyMiniappConfigService iTaThirdPartyMiniappConfigService;

    @Autowired
    private IMiniAppService miniAppService;

    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/thirdPartyMiniapp",method= RequestMethod.GET)
    public ResponseBean taThirdPartyMiniappConfigList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                                      @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                                      HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaThirdPartyMiniappConfig> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaThirdPartyMiniappConfig> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("org_id", getOrgId(request));

            IPage<TaThirdPartyMiniappConfig> result = iTaThirdPartyMiniappConfigService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taThirdPartyMiniappConfigList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taThirdPartyMiniappConfig 实体对象
     * @return
     */
    @RequestMapping(value="/admin/thirdPartyMiniapp/add",method= RequestMethod.POST)
    public ResponseBean taThirdPartyMiniappConfigAdd(@RequestBody TaThirdPartyMiniappConfig taThirdPartyMiniappConfig,HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            taThirdPartyMiniappConfig.setOrgId(getOrgId(request));
            if (iTaThirdPartyMiniappConfigService.save(taThirdPartyMiniappConfig)){
                responseBean.addSuccess(taThirdPartyMiniappConfig);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taThirdPartyMiniappConfigAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taThirdPartyMiniappConfig/{id}", method= RequestMethod.DELETE)
    public ResponseBean taThirdPartyMiniappConfigDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaThirdPartyMiniappConfigService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taThirdPartyMiniappConfigDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param taThirdPartyMiniappConfig 实体对象
     * @return
     */
    @RequestMapping(value="/admin/thirdPartyMiniapp/update",method= RequestMethod.PUT)
    public ResponseBean taThirdPartyMiniappConfigUpdate(@RequestBody TaThirdPartyMiniappConfig taThirdPartyMiniappConfig){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaThirdPartyMiniappConfigService.updateById(taThirdPartyMiniappConfig)){
                responseBean.addSuccess(taThirdPartyMiniappConfig);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taThirdPartyMiniappConfigUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/thirdPartyMiniapp/{id}",method= RequestMethod.GET)
    public ResponseBean taThirdPartyMiniappConfigGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaThirdPartyMiniappConfigService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taThirdPartyMiniappConfigDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 第三方生成二维码
     * @return
     */
    @PostMapping("/third/qrcode")
    public ResponseBean thirdQrcode(@RequestBody String paramsStr, HttpServletRequest request) {
        //获取H5项目相关信息
        String xAppid = request.getHeader("x-appid");
        QueryWrapper<TaThirdPartyMiniappConfig> taThirdPartyMiniappConfigQueryWrapper = new QueryWrapper<>();

        taThirdPartyMiniappConfigQueryWrapper.eq("appid", xAppid);
        TaThirdPartyMiniappConfig taThirdPartyMiniappConfig = iTaThirdPartyMiniappConfigService.getOne(taThirdPartyMiniappConfigQueryWrapper);
        if (null == taThirdPartyMiniappConfig){
            return ResponseBean.error("不存在的H5活动",ResponseBean.ERROR_UNAVAILABLE);
        }
        String appid = request.getHeader("appid");
        return miniAppService.getQrCode(paramsStr, appid);
    }
}
